@@ -8,7 +8,7 @@ from fps.hooks import register_router  # type: ignore
 from fastapi import APIRouter, WebSocket, WebSocketDisconnect, Depends, status
 import fastapi
 
-from fps_auth.routes import cookie_authentication  # type: ignore
+from fps_auth.backends import cookie_authentication  # type: ignore
 from fps_auth.db import get_user_db  # type: ignore
 from fps_auth.config import get_auth_config  # type: ignore
 
